@@ -15,8 +15,13 @@ print "  ፈተና  ፩፦ ዓለምፀሐይ matches /([=አ=])ለም[=ጸ=][=
 print "  ፈተና  ፪፦ ዓለምፀሐይ contains /[#ለ#]ም/\n"              if ( $ፈተና =~ /[#ለ#]ም/ );
 print "  ፈተና  ፫፦ ዓለምፀሐይ contains /[#4#]ለ/\n"              if ( $ፈተና =~ /[#4#]ለ/ );
 
-
 print "Form Range Tests...\n";
+print "  ፈተና  ፫.፩፦ ዓለምፀሐይ contains /[#4-6#]ለ/\n"          if ( $ፈተና =~ /[#4-6#]ለ/ );
+print "  ፈተና  ፫.፪፦ ዓለምፀሐይ contains /[#4,6#]ለ/\n"          if ( $ፈተና =~ /[#4,6#]ለ/ );
+print "  ፈተና  ፫.፫፦ ዓለምፀሐይ contains /[#ለ-መ#]/\n"           if ( $ፈተና =~ /[#ለ-መ#]/ );
+print "  ፈተና  ፫.፬፦ ዓለምፀሐይ contains /[#ለ-መ#]/\n"           if ( $ፈተና =~ /[#ለመ#]/ );
+
+print "Form Range Operator Tests...\n";
 print "  ፈተና  ፬፦ ዓለምፀሐይ contains መ%{4-7}\n"               if ( $ፈተና =~ /መ%{4-7}/ );
 print "  ፈተና  ፭፦ ዓለምፀሐይ contains ፀ%{1,3-5,7}\n"           if ( $ፈተና =~ /ፀ%{1,3-5,7}/ );
 
